==> migrate_wizard-1.0.8-alpha1.tar.gz: migrate_wizard/src/EventSubscriber/MWCasSubscriber.php <==
<?php

namespace Drupal\migrate_wizard\EventSubscriber;

use Drupal\cas\Service\CasUserManager;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\migrate\Event\MigrateEvents;
use Drupal\migrate\Event\MigratePostRowSaveEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * This class is executed after row is saved.
 */
class MWCasSubscriber implements EventSubscriberInterface {

    /**
   * The entity type manager.
   *
   * @var Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The Cas user manager.
   *
   * @var Drupal\cas\Service\CasUserManager
   */
  protected $casUserManager;

  /**
   * Constructs a new migration subscriber.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity field manager service.
   * @param \Drupal\cas\Service\CasUserManager $cas_user_manager
   *   The entity display repository.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, CasUserManager $cas_user_manager) {
    $this->entityTypeManager = $entity_type_manager;
    $this->casUserManager = $cas_user_manager;
  }

  /**
   * Set the CAS user name to the user name entity after migrate.
   */
  public function setCasUserName(MigratePostRowSaveEvent $event) {
    $source_config = $event->getMigration()->getSourceConfiguration();
    $migration_id = $event->getMigration()->id();
    if ($migration_id == "users" && isset($source_config["import_cas"]) && $source_config["import_cas"]) {
      $row = $event->getRow();
      $cas_name = $row->getSourceProperty("cas_name");
      if (!empty($cas_name)) {
        $destination_uids = $event->getDestinationIdValues();
        $new_uid = end($destination_uids);
        $account = $this->entityTypeManager
          ->getStorage('user')
          ->load($new_uid);
        $this->casUserManager->setCasUsernameForAccount($account, $cas_name);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events = [];
    if (\Drupal::hasService('cas.user_manager')) {
      $events[MigrateEvents::POST_ROW_SAVE][] = ['setCasUserName', 0];
    }
    return $events;
  }
}

==> migrate_wizard-2.0.2-alpha1.tar.gz: migrate_wizard/src/EventSubscriber/MWCasSubscriber.php <==
<?php

namespace Drupal\migrate_wizard\EventSubscriber;

use Drupal\cas\Service\CasUserManager;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\migrate\Event\MigrateEvents;
use Drupal\migrate\Event\MigratePostRowSaveEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * This class is executed after row is saved.
 */
class MWCasSubscriber implements EventSubscriberInterface {

    /**
   * The entity type manager.
   *
   * @var Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new migration subscriber.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity field manager service.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * Set the CAS user name to the user name entity after migrate.
   */
  public function setCasUserName(MigratePostRowSaveEvent $event) {
    $source_config = $event->getMigration()->getSourceConfiguration();
    $migration_id = $event->getMigration()->id();
    if ($migration_id == "users" && isset($source_config["import_cas"]) && $source_config["import_cas"]) {
      $casUserManager = \Drupal::service('cas.user_manager');
      $row = $event->getRow();
      $cas_name = $row->getSourceProperty("cas_name");
      if (!empty($cas_name)) {
        $destination_uids = $event->getDestinationIdValues();
        $new_uid = end($destination_uids);
        $account = $this->entityTypeManager
          ->getStorage('user')
          ->load($new_uid);
        $casUserManager->setCasUsernameForAccount($account, $cas_name);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[MigrateEvents::POST_ROW_SAVE][] = ['setCasUserName', 0];
    return $events;
  }
}
